import CONST from './const.js';
import * as Extract from './lib/extract.js';
import * as Record from './lib/records.js';
import { get_version, upgrade_psbt } from './lib/api.js';
import { create_psbt } from './lib/create.js';
import { decode_psbt } from './lib/decode.js';
import { encode_psbt } from './lib/encode.js';
import { finalize_psbt } from './lib/finalize.js';
import { parse_psbt } from './lib/parse.js';
import { update_psbt_global, update_psbt_input, update_psbt_output, update_txdata, update_txin, update_txout } from './lib/update.js';
export * from './lib/api.js';
export * from './lib/create.js';
export * from './lib/decode.js';
export * from './lib/encode.js';
export * from './lib/extract.js';
export * from './lib/finalize.js';
export * from './lib/parse.js';
export * from './lib/update.js';
export * from './types/index.js';
export { CONST };
declare const _default: {
    create: typeof create_psbt;
    encode: typeof encode_psbt;
    decode: typeof decode_psbt;
    finalize: typeof finalize_psbt;
    parse: typeof parse_psbt;
    upgrade: typeof upgrade_psbt;
    version: typeof get_version;
    extract: {
        global: {
            txdata: typeof Extract.extract_txdata;
        };
        input: {
            prevout: typeof Extract.extract_input_prevout;
            sighash: typeof Extract.extract_input_sighash;
            sigflag: typeof Extract.extract_input_sigflag;
            witness: {
                segwit: typeof Extract.extract_input_segwit_data;
                taproot: typeof Extract.extract_input_taproot_data;
            };
        };
    };
    record: {
        global: {
            collect: typeof Record.collect_global_record;
            find: typeof Record.find_global_record;
            get: typeof Record.get_global_record;
            has: typeof Record.has_global_record;
            remove: typeof Record.remove_global_record;
            update: typeof Record.update_global_record;
        };
        input: {
            collect: typeof Record.collect_input_record;
            find: typeof Record.find_input_record;
            get: typeof Record.get_input_record;
            has: typeof Record.has_input_record;
            remove: typeof Record.remove_input_record;
            update: typeof Record.update_input_record;
        };
        output: {
            collect: typeof Record.collect_input_record;
            find: typeof Record.find_output_record;
            get: typeof Record.get_output_record;
            has: typeof Record.has_output_record;
            remove: typeof Record.remove_output_record;
            update: typeof Record.update_output_record;
        };
    };
    update: {
        records: {
            global: typeof update_psbt_global;
            input: typeof update_psbt_input;
            output: typeof update_psbt_output;
        };
        tx: {
            data: typeof update_txdata;
            input: typeof update_txin;
            output: typeof update_txout;
        };
    };
};
export default _default;
