import CONST from './const.js';
import * as Extract from './lib/extract.js';
import * as Record from './lib/records.js';
import { get_version, upgrade_psbt } from './lib/api.js';
import { create_psbt } from './lib/create.js';
import { decode_psbt } from './lib/decode.js';
import { encode_psbt } from './lib/encode.js';
import { finalize_psbt } from './lib/finalize.js';
import { parse_psbt } from './lib/parse.js';
import { update_psbt_global, update_psbt_input, update_psbt_output, update_txdata, update_txin, update_txout } from './lib/update.js';
export * from './lib/api.js';
export * from './lib/create.js';
export * from './lib/decode.js';
export * from './lib/encode.js';
export * from './lib/extract.js';
export * from './lib/finalize.js';
export * from './lib/parse.js';
export * from './lib/update.js';
export * from './types/index.js';
export { CONST };
export default {
    create: create_psbt,
    encode: encode_psbt,
    decode: decode_psbt,
    finalize: finalize_psbt,
    parse: parse_psbt,
    upgrade: upgrade_psbt,
    version: get_version,
    extract: {
        global: {
            txdata: Extract.extract_txdata
        },
        input: {
            prevout: Extract.extract_input_prevout,
            sighash: Extract.extract_input_sighash,
            sigflag: Extract.extract_input_sigflag,
            witness: {
                segwit: Extract.extract_input_segwit_data,
                taproot: Extract.extract_input_taproot_data
            }
        }
    },
    record: {
        global: {
            collect: Record.collect_global_record,
            find: Record.find_global_record,
            get: Record.get_global_record,
            has: Record.has_global_record,
            remove: Record.remove_global_record,
            update: Record.update_global_record
        },
        input: {
            collect: Record.collect_input_record,
            find: Record.find_input_record,
            get: Record.get_input_record,
            has: Record.has_input_record,
            remove: Record.remove_input_record,
            update: Record.update_input_record
        },
        output: {
            collect: Record.collect_input_record,
            find: Record.find_output_record,
            get: Record.get_output_record,
            has: Record.has_output_record,
            remove: Record.remove_output_record,
            update: Record.update_output_record
        }
    },
    update: {
        records: {
            global: update_psbt_global,
            input: update_psbt_input,
            output: update_psbt_output
        },
        tx: {
            data: update_txdata,
            input: update_txin,
            output: update_txout
        }
    }
};
