import { Buff } from '@cmdcode/buff';
import { get_io_counts } from './util.js';
import { assert, check } from '../util/index.js';
import CONST from '../const.js';
import * as verify from './verify.js';
export function decode_psbt(psbt_str) {
    const stream = (check.is_hex(psbt_str))
        ? Buff.hex(psbt_str).stream
        : Buff.base64(psbt_str).stream;
    const magic = stream.read(5).hex;
    verify.psbt_magic(magic);
    const global = decode_keypairs(stream, CONST.PSBT_GLOBAL_TYPE_MAP);
    const [vin_count, out_count] = get_io_counts(global);
    const inputs = [];
    for (let i = 0; i < vin_count; i++) {
        const pairs = decode_keypairs(stream, CONST.PSBT_INPUT_TYPE_MAP);
        inputs.push(pairs);
    }
    const outputs = [];
    for (let i = 0; i < out_count; i++) {
        const pairs = decode_keypairs(stream, CONST.PSBT_OUTPUT_TYPE_MAP);
        outputs.push(pairs);
    }
    assert.end_of_stream(stream);
    const psbt = { global, inputs, outputs };
    verify.psbt_schema(psbt);
    return psbt;
}
export function decode_psbt_globals(psbt_str) {
    const stream = (check.is_hex(psbt_str))
        ? Buff.hex(psbt_str).stream
        : Buff.base64(psbt_str).stream;
    const magic = stream.read(5).hex;
    verify.psbt_magic(magic);
    return decode_keypairs(stream, CONST.PSBT_GLOBAL_TYPE_MAP);
}
function decode_keypairs(stream, keymap) {
    const pairs = [];
    while (stream.peek(1).num !== 0x00) {
        const kp = decode_keypair(stream, keymap);
        pairs.push(kp);
    }
    assert.is_zero_byte(stream.read(1));
    return pairs;
}
function decode_keypair(stream, keymap) {
    const klen = stream.read_varint();
    const kdat = stream.read(klen).stream;
    const type = kdat.read_varint();
    let key = (kdat.size !== 0)
        ? kdat.read(kdat.size).hex
        : undefined;
    let label = keymap[type];
    if (type === 0xFC) {
        assert.exists(key);
        const pdat = Buff.bytes(key).stream;
        const plen = pdat.read_varint();
        label = pdat.read(plen).str;
        key = pdat.read(pdat.size).hex;
    }
    const vlen = stream.read_varint();
    const value = stream.read(vlen).hex;
    return { key, label, value };
}
