import { Buff } from '@cmdcode/buff';
import { encode_script } from '@scrow/tapscript/script';
import { encode_witness } from './tx.js';
import { has_input_record, update_global_record, update_input_record, update_output_record } from './records.js';
export function populate_psbt(psbt, txdata) {
    populate_txglobal_data(psbt.global, txdata);
    for (let i = 0; i < txdata.vin.length; i++) {
        populate_txin_data(psbt.inputs[i], txdata.vin[i]);
    }
    for (let i = 0; i < txdata.vout.length; i++) {
        populate_txout_data(psbt.outputs[i], txdata.vout[i]);
    }
}
export function populate_txglobal_data(global, txdata) {
    update_global_record(global, { label: 'TX_VERSION', value: Buff.num(txdata.version, 4).hex });
    update_global_record(global, { label: 'FALLBACK_LOCKTIME', value: Buff.num(txdata.locktime, 4).hex });
    update_global_record(global, { label: 'INPUT_COUNT', value: Buff.num(txdata.vin.length, 4).hex });
    update_global_record(global, { label: 'OUTPUT_COUNT', value: Buff.num(txdata.vout.length, 4).hex });
}
export function populate_txin_data(input, txin) {
    update_input_record(input, { label: 'PREVIOUS_TXID', value: txin.txid });
    update_input_record(input, { label: 'OUTPUT_INDEX', value: Buff.num(txin.vout, 4).hex });
    update_input_record(input, { label: 'SEQUENCE', value: Buff.num(txin.sequence, 4).hex });
    if (txin.prevout !== undefined) {
        const { value, scriptPubKey } = txin.prevout;
        const prevout = Buff.join([Buff.big(value), encode_script(scriptPubKey, true)]).hex;
        update_input_record(input, { label: 'WITNESS_UTXO', value: prevout });
    }
    if (txin.witness.length > 0 && !has_input_record(input, 'FINAL_SCRIPTWITNESS')) {
        update_input_record(input, { label: 'FINAL_SCRIPTWITNESS', value: encode_witness(txin.witness) });
    }
}
export function populate_txout_data(output, txout) {
    update_output_record(output, { label: 'AMOUNT', value: Buff.big(txout.value, 8).hex });
    update_output_record(output, { label: 'SCRIPT', value: encode_script(txout.scriptPubKey, true).hex });
}
