import { assert } from '../util/index.js';
export function get_record_type(keymap, label) {
    const ent = Object.entries(keymap).find(e => e[1] === label);
    assert.exists(ent, 'type does not exist for label: ' + label);
    return Number(ent[0]);
}
export function collect_global_record(records, label) {
    return collect_record(records, label);
}
export function find_global_record(records, label) {
    return find_record(records, label);
}
export function has_global_record(records, label) {
    return has_record(records, label);
}
export function get_global_record(records, label) {
    return get_record(records, label);
}
export function remove_global_record(records, label) {
    remove_record(records, label);
}
export function update_global_record(records, record) {
    update_record(records, record);
}
export function collect_input_record(records, label) {
    return collect_record(records, label);
}
export function find_input_record(records, label) {
    return find_record(records, label);
}
export function has_input_record(records, label) {
    return has_record(records, label);
}
export function get_input_record(records, label) {
    return get_record(records, label);
}
export function remove_input_record(records, label) {
    remove_record(records, label);
}
export function update_input_record(records, updated) {
    update_record(records, updated);
}
export function collect_output_record(records, label) {
    return collect_record(records, label);
}
export function find_output_record(records, label) {
    return find_record(records, label);
}
export function has_output_record(records, label) {
    return has_record(records, label);
}
export function get_output_record(records, label) {
    return get_record(records, label);
}
export function remove_output_record(records, label) {
    remove_record(records, label);
}
export function update_output_record(records, updated) {
    update_record(records, updated);
}
function collect_record(records, label) {
    return records.filter(e => (e.label === label && e.key !== undefined));
}
function find_record(records, label) {
    return records.find(e => e.label === label);
}
function has_record(records, label) {
    const record = find_record(records, label);
    return record !== undefined;
}
function get_record(records, label) {
    const record = find_record(records, label);
    assert.exists(record, 'record not found: ' + label);
    return record;
}
function remove_record(records, label) {
    for (let i = 0; i < records.length; i++) {
        const record = records[i];
        if (record.label === label) {
            records.splice(i, 1);
        }
    }
}
function update_record(records, updated) {
    const idx = records.findIndex(e => e.label === updated.label);
    if (idx === -1) {
        records.push(updated);
    }
    else {
        records[idx] = updated;
    }
}
export default {
    global: {
        find: find_global_record,
        get: get_global_record,
        has: has_global_record,
        remove: remove_global_record,
        update: update_global_record
    },
    input: {
        find: find_input_record,
        get: get_input_record,
        has: has_input_record,
        remove: remove_input_record,
        update: update_input_record
    },
    output: {
        find: find_output_record,
        get: get_output_record,
        has: has_output_record,
        remove: remove_output_record,
        update: update_output_record
    }
};
