import { Buff, Stream } from '@cmdcode/buff';
import { decode_script, encode_script } from '@scrow/tapscript/script';
import { check } from '../util/index.js';
export function decode_prevout(bytes) {
    const stream = new Stream(bytes);
    const value = stream.read(8).big;
    const script = decode_script(stream.data, true);
    return { value, scriptPubKey: script };
}
export function decode_witness(bytes) {
    const stream = Buff.bytes(bytes).stream;
    const stack = [];
    const count = stream.read_varint();
    for (let i = 0; i < count; i++) {
        const word = read_data(stream, true);
        stack.push(word ?? '');
    }
    return stack;
}
export function encode_witness(data) {
    const buffer = [];
    if (Array.isArray(data)) {
        const count = Buff.calc_varint(data.length);
        buffer.push(count);
        for (const entry of data) {
            const bytes = (!check.is_empty(entry))
                ? encode_script(entry, true)
                : new Buff(0);
            buffer.push(bytes);
        }
        return Buff.join(buffer).hex;
    }
    else {
        return Buff.bytes(data).hex;
    }
}
function read_data(stream, varint) {
    const size = (varint === true)
        ? stream.read_varint('le')
        : stream.size;
    return size > 0
        ? stream.read(size).hex
        : null;
}
