import { parse_psbt } from './parse.js';
import { assert } from '../util/index.js';
import { update_global_record, update_input_record, update_output_record } from './records.js';
import { populate_psbt, populate_txin_data, populate_txout_data } from './populate.js';
import * as verify from './verify.js';
export function update_psbt_global(psbt, template) {
    const { global, inputs, outputs } = parse_psbt(psbt);
    for (const key of template ?? []) {
        update_global_record(global, key);
    }
    return { global, inputs, outputs };
}
export function update_psbt_input(psbt, index, template) {
    const { global, inputs, outputs } = parse_psbt(psbt);
    for (const key of template ?? []) {
        update_input_record(inputs[index], key);
    }
    return { global, inputs, outputs };
}
export function update_psbt_output(psbt, index, template) {
    const { global, inputs, outputs } = parse_psbt(psbt);
    for (const key of template ?? []) {
        update_output_record(outputs[index], key);
    }
    return { global, inputs, outputs };
}
export function update_txdata(psbt, txdata) {
    const { global, inputs, outputs } = psbt;
    verify.psbt_version(global, 2);
    assert.ok(txdata.vin.length === inputs.length, 'PSBT input length does not match unsigned tx');
    assert.ok(txdata.vout.length === outputs.length, 'PSBT output length does not match unsigned tx');
    populate_psbt({ global, inputs, outputs }, txdata);
    return { global, inputs, outputs };
}
export function update_txin(psbt, txin, index) {
    const { global, inputs, outputs } = parse_psbt(psbt);
    verify.psbt_version(global, 2);
    assert.ok(inputs.length > index, 'index exceeds psbt input count');
    populate_txin_data(inputs[index], txin);
    return { global, inputs, outputs };
}
export function update_txout(psbt, txout, index) {
    const { global, inputs, outputs } = parse_psbt(psbt);
    verify.psbt_version(global, 2);
    assert.ok(outputs.length > index, 'index exceeds psbt input count');
    populate_txout_data(outputs[index], txout);
    return { global, inputs, outputs };
}
