import { Buff }          from '@cmdcode/buff'
import { populate_psbt } from './populate.js'
import { PSBTData }      from '@/types/index.js'

import { get_psbt_version, get_unsigned_tx } from './util.js'
import { parse_global, parse_psbt }          from './parse.js'

import {
  remove_global_record,
  update_global_record
} from './records.js'

/**
 * Get the version of a PSBT without fully parsing the body.
 */
export function get_version (psbt : string | PSBTData) {
  const global = parse_global(psbt)
  return get_psbt_version(global)
}

/**
 * Upgrade a version 0 PSBT to version 2.
 */
export function upgrade_psbt (psbt : string | PSBTData) {
  const pdata = parse_psbt(psbt)
  // Extract the transaction hex from the global data.
  const txhex = get_unsigned_tx(pdata.global)
  // Populate the PSBT with data from the transaction.
  populate_psbt(pdata, txhex)
  // Delete the unsigned transaction field.
  remove_global_record(pdata.global, 'UNSIGNED_TX')
  // Update the version field.
  update_global_record(pdata.global, { label: 'VERSION', value: Buff.num(2, 4).hex })
  //
  return pdata
}
