import { TxData }        from '@scrow/tapscript'
import { parse_tx }      from '@scrow/tapscript/tx'
import { populate_psbt } from './populate.js'

import {
  update_psbt_global,
  update_psbt_input,
  update_psbt_output
} from './update.js'

import { PSBTData, PSBTemplate } from '@/types/index.js'

export function create_psbt (
  txinput   : string | TxData,
  template ?: PSBTemplate
) : PSBTData {
  // Create an empty PSBT object.
  const psbt : PSBTData = {  global: [], inputs: [], outputs: [] }
  // Parse the transaction data.
  const txdata = parse_tx(txinput)
  // Add the transaction data to the PSBT.
  populate_psbt(psbt, txdata)
  //
  if (template !== undefined) {
    if (template.global !== undefined) {
      update_psbt_global(psbt, template.global)
    }
    if (template.inputs !== undefined) {
      for (let i = 0; i < template.inputs.length; i++) {
        update_psbt_input(psbt, i, template.inputs[i])
      }
    }
    if (template.outputs !== undefined) {
      for (let i = 0; i < template.outputs.length; i++) {
        update_psbt_output(psbt, i, template.outputs[i])
      }
    }
  }
  // Return the PSBT.
  return psbt
}
