import { PSBTData, PSBTGlobalRecord }       from '@/types/index.js'
import { decode_psbt, decode_psbt_globals } from './decode.js'

import PSBTSchema from '@/schema/index.js'

export function parse_psbt (psbt : string | PSBTData) : PSBTData {
  if (typeof psbt === 'string') {
    try {
      return decode_psbt(psbt)
    } catch (err) {
      throw new Error('Failed to decode PSBT string.')
    }
  } else {
    try {
      return PSBTSchema.parse(psbt) as PSBTData
    } catch (err) {
      throw new Error('PSBT data failed validation.')
    }
  }
}

export function parse_global (psbt : string | PSBTData) : PSBTGlobalRecord[] {
  if (typeof psbt === 'string') {
    try {
      return decode_psbt_globals(psbt)
    } catch (err) {
      throw new Error('Failed to decode PSBT string.')
    }
  } else {
    try {
      return psbt.global
    } catch (err) {
      throw new Error('PSBT data failed validation.')
    }
  }
}
