import { Buff }               from '@cmdcode/buff'
import { decode_tx }          from '@scrow/tapscript/tx'
import { PSBTGlobalRecord }   from '@/types/index.js'

import {
  find_global_record,
  get_global_record
} from './records.js'

export function get_psbt_version (global : PSBTGlobalRecord[]) {
  const version = find_global_record(global, 'VERSION')
  return (version !== undefined)
    ? Buff.hex(version.value).num
    : 0
}

export function get_unsigned_tx (global : PSBTGlobalRecord[]) {
  const txrec = get_global_record(global, 'UNSIGNED_TX')
  return decode_tx(txrec.value, false)
}

export function get_io_counts (global : PSBTGlobalRecord[]) {
  // Get the version of the PSBT.
  const version = get_psbt_version(global)
  // If we are on version 2:
  if (version === 2) {
    // Get the input and output counts.
    const vin_kp = get_global_record(global, 'INPUT_COUNT')
    const out_kp = get_global_record(global, 'OUTPUT_COUNT')
    const vin_ct = Buff.bytes(vin_kp.value).num
    const out_ct = Buff.bytes(out_kp.value).num
    return [ vin_ct, out_ct ]
  } else {
    // Parse the unsigned transaction.
    const keypair = get_global_record(global, 'UNSIGNED_TX')
    const txdata  = decode_tx(keypair.value, false)
    // Set the input and output counts.
    const vin_ct = txdata.vin.length
    const out_ct = txdata.vout.length
    return [ vin_ct, out_ct ]
  }
}
