import { get_psbt_version } from '@/lib/util.js'

import {
  has_global_record,
  has_input_record,
  has_output_record
} from '@/lib/records.js'

import {
  PSBTData,
  PSBTGlobalKeys,
  PSBTGlobalRecord,
  PSBTInputKeys,
  PSBTInputRecord,
  PSBTOutputKeys,
  PSBTOutputRecord
} from '@/types/psbt.js'

import CONST  from '@/const.js'
import Schema from '@/schema/index.js'

export function psbt_magic (magic : string) {
  if (magic !== CONST.PSBT_MAGIC_BYTES) {
    throw new Error('invalid magic for psbt: ' + magic)
  }
}

export function psbt_version (global : PSBTGlobalRecord[], version = 2) {
  const psbt_version = get_psbt_version(global)
  if (psbt_version !== version) {
    throw new Error(`invalid version for psbt: ${psbt_version} !== ${version}`)
  }
}

export function psbt_schema (psbt : any) : asserts psbt is PSBTData {
  const res = Schema.safeParse(psbt)
  if (!res.success) {
    throw new Error('PSBT schema is invalid.')
  }
}

export function global_type_exists (
  records : PSBTGlobalRecord[],
  label   : PSBTGlobalKeys
) {
  if (!has_global_record(records, label)) {
    throw new Error('global type does not exist: ' + label)
  }
}

export function input_type_exists (
  records : PSBTInputRecord[],
  label   : PSBTInputKeys
) {
  if (!has_input_record(records, label)) {
    throw new Error('global type does not exist: ' + label)
  }
}

export function output_type_exists (
  records : PSBTOutputRecord[],
  label   : PSBTOutputKeys
) {
  if (!has_output_record(records, label)) {
    throw new Error('global type does not exist: ' + label)
  }
}
