import { Buff, Bytes, Stream } from '@cmdcode/buff'

import * as check from './check.js'

export function ok (
  value    : unknown,
  message ?: string
) : asserts value {
  if (value === false) {
    throw new Error(message ?? 'Assertion failed!')
  }
}

export function exists <T> (
  value : T | null,
  msg  ?: string
  ) : asserts value is NonNullable<T> {
  if (!check.exists(value)) {
    throw new Error(msg ?? 'Value is null or undefined!')
  }
}

export function is_zero_byte (byte : Bytes) {
  const stop_byte = new Buff(byte)
  if (stop_byte.length !== 1 || stop_byte[0] !== 0) {
    throw new Error('stream has invalid stop byte: ' + stop_byte)
  }
}

export function end_of_stream (stream : Stream) {
  if (stream.size !== 0) {
    throw new Error('stream has excess bytes: ' + new Buff(stream.data).hex)
  }
}

export function array_idx_exists <T = any> (
  index  : number,
  array ?: Array<T>,
  msg   ?: string
) : asserts array is Array<T> {
  if (array?.at(index) === undefined) {
    throw new Error(msg ?? 'array is empty at index: ' + index)
  }
}
